@@ -35,10 +35,10 @@ def parse_page_range_expression(exp):
 class NaverKinCrawler(BaseCrawler):
     COMMENT_PAGE_COUNT = 100
     PROXIES_LIST = [
-        # None,
         # {'https':'103.37.141.68:80'},
+        # None,
         # {'https':'140.227.61.156:23456'},
-        # {'https':'121.254.195.12:8080'},
+        {'https':'121.254.195.12:8080'},
     ]
 
     urlorders = [
@@ -52,6 +52,7 @@ class NaverKinCrawler(BaseCrawler):
             r'https://kin.naver.com/qna/detail.naver\?d1id=(?P<d1id>\d+)&dirId=(?P<dirId>\d+)&docId=(?P<docId>\d+).+$',
             fields=['d1id', 'dirId', 'docId'],
             parser='kin_detail_parser', extractor=detail,
+            refresh=True,
             name='kin_detail',
         ),
         urlrender(
@@ -204,7 +205,7 @@ def event_listener(module, event, count):
 def test_naverkin(keywords, page_range):
     nkc = NaverKinCrawler(keywords, page_range,
         settings=settings,
-        # crawl_listener=event_listener
+        crawl_listener=event_listener
     )
     nkc.crawl()
     return nkc
